@@ -6,6 +6,8 @@ function (x, digits = max(3, getOption("digits") - 4), ...) {
     mat[lower.tri(mat)] <- sprintf("%6.3f", format(mat[lower.tri(mat)]))
     ind <- mat[lower.tri(mat)] == paste(" 0.", paste(rep(0, digits), collapse = ""), sep = "")
     mat[lower.tri(mat)][ind] <- "<0.001"
+    ind <- mat[lower.tri(mat)] == paste(" 1.", paste(rep(0, digits), collapse = ""), sep = "")
+    mat[lower.tri(mat)][ind] <- ">0.999"    
     mat[upper.tri(mat)] <- sprintf("%6.3f", format(mat[upper.tri(mat)]))
     diag(mat) <- " *****"
     cat("\n")
