@@ -3,12 +3,12 @@
 
 
 ## Fit the Rasch model using ltm()
-ltm(Lsat ~ z1, constr = cbind(1:length(Lsat), 2, 1))
-rasch(Lsat, constr = cbind(length(Lsat) + 1, 1))
+ltm(LSAT ~ z1, constr = cbind(1:length(LSAT), 2, 1))
+rasch(LSAT, constr = cbind(length(LSAT) + 1, 1))
 
 
 ## ltm() fits latent trait models up to two latent variables
-fit <- ltm(Wirs ~ z1 + z2)
+fit <- ltm(WIRS ~ z1 + z2)
 
 ## use the following to produce the plot of standardized loadings,
 plot(fit, type = "loadings")
@@ -18,7 +18,6 @@ plot(fit, ticktype = "detailed", theta = 30, phi = 30, expand = 0.5, d = 2, cex
 
 
 ## ltm() can also be used to include nonlinear latent terms
-set.seed(123321) # because of the random starting values used
 fit <- ltm(Mobility ~ z1 * z2)
 
 plot(fit, ticktype = "detailed", theta = 30, phi = 30, expand = 0.5, d = 2, cex = 0.7)
